@@ -1,5 +1,6 @@
 import numpy as np
 import matplotlib.pyplot as plt
+import cv2
 from mpl_toolkits.mplot3d import Axes3D
 
 def axisEqual3D(ax):
@@ -15,7 +16,7 @@ def axisEqual3D(ax):
         getattr(ax, 'set_{}lim'.format(dim))(ctr - r, ctr + r)
 
 def plotCamera(ax, R, t, c, scale):
-    """Plot the camera in 3D
+    """Plot a camera in 3D
 
     Args:
         ax (Axis3D): target axis
@@ -42,3 +43,34 @@ def plotCamera(ax, R, t, c, scale):
     ax.plot(L1234[:,0], L1234[:,1], L1234[:,2], "-", color=c)
 
     #axisEqual3D(ax)
+
+def plotCameras(camera_params, points_3d):
+    """Plot cameras and points in 3D
+
+    Args:
+        camera_params: Nx17 camera parameters (rvec, tvec, f, ...)
+        points_3d: Mx3 3D points
+    """
+    assert points_3d.shape[1] == 3
+    Nc = len(camera_params)
+
+    R = []
+    t = []
+    for c in camera_params:
+        R.append(cv2.Rodrigues(c[:3])[0])
+        t.append(c[3:6])
+
+    fig = plt.figure()
+    ax = Axes3D(fig, auto_add_to_figure=False)
+    fig.add_axes(ax)
+    ax.set_xlim(-1, 1)
+    ax.set_ylim(-1, 1)
+    ax.set_zlim(0, 1)
+    ax.plot(points_3d[:,0], points_3d[:,1], points_3d[:,2], "o")
+    cmap = plt.get_cmap("tab10")
+    for i in range(Nc):
+        plotCamera(ax, R[i].T, - R[i].T @ t[i][:,None], cmap(i), 0.05)
+    #plt.savefig('a.png')
+    fig.show()
+    return fig
+
